@@ -1,8 +1,10 @@
 /* GNOME-DB Components
- * Copyright (C) 2000-2002 The GNOME Foundation.
+ *
+ * Copyright (C) 2000 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +36,7 @@
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <libgnomedb/gnome-db-data-widget.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include "dsn-config.h"
 #include "dsn-properties-dialog.h"
@@ -79,7 +82,7 @@ show_data_sources (DsnConfigPrivate *priv)
 		value_list = g_list_append (NULL, gda_value_new_string (dsn_info->name));
 		value_list = g_list_append (value_list, gda_value_new_string (dsn_info->description));
 
-		gda_data_model_append_row (model, (const GList *) value_list);
+		gda_data_model_append_values (model, (const GList *) value_list);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
@@ -88,7 +91,7 @@ show_data_sources (DsnConfigPrivate *priv)
 	gnome_db_config_free_data_source_list (dsn_list);
 
 	/* display the new data model */
-	gnome_db_grid_set_model (GNOME_DB_GRID (priv->dsn_list), model);
+	gnome_db_grid_set_gda_model (GNOME_DB_GRID (priv->dsn_list), NULL, model);
 	g_object_unref (G_OBJECT (model));
 }
 
@@ -125,6 +128,7 @@ list_popup_cb (GnomeDbGrid *grid, GtkMenu *menu, gpointer user_data)
 {
 	GtkWidget *item_delete, *item_properties;
 	gboolean ok;
+	GList *list;
 
 	item_delete = gnome_db_new_menu_item (GTK_STOCK_DELETE,
 					      TRUE,
@@ -135,7 +139,10 @@ list_popup_cb (GnomeDbGrid *grid, GtkMenu *menu, gpointer user_data)
 						  G_CALLBACK (list_popup_properties_cb),
 						  user_data);
 
-	ok = gnome_db_grid_get_selection (grid) != NULL;
+	list = gnome_db_grid_get_selection (grid);
+	ok = list != NULL;
+	if (list)
+		g_list_free (list);
 	gtk_widget_set_sensitive (item_delete, ok);
 	gtk_widget_set_sensitive (item_properties, ok);
 
@@ -177,6 +184,8 @@ dsn_config_new (void)
 
 	/* create the data source list */
 	priv->dsn_list = gnome_db_grid_new ();
+	gnome_db_data_widget_global_show_actions (GNOME_DB_DATA_WIDGET (priv->dsn_list), FALSE);
+	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->dsn_list), 0, FALSE);
 
 	title = g_strdup_printf ("<b>%s</b>\n%s", _("Data Sources"),
 				 _("Configured data sources in the system"));
@@ -235,12 +244,12 @@ dsn_config_edit_properties (GtkWidget *dsn)
 	gchar *str;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-
+	
 	selection = gnome_db_grid_get_selection (GNOME_DB_GRID (priv->dsn_list));
 	if (!selection)
 		return;
 
-	model = gnome_db_grid_get_model (GNOME_DB_GRID (priv->dsn_list));
+	model = gnome_db_grid_get_gda_model (GNOME_DB_GRID (priv->dsn_list));
 	if (!GDA_IS_DATA_MODEL (model))
 		return;
 
@@ -264,7 +273,7 @@ foreach_remove_cb (GnomeDbGrid *grid, gint row, gpointer user_data)
 	gchar *dsn;
 
 	priv = (DsnConfigPrivate *) user_data;
-	model = gnome_db_grid_get_model (GNOME_DB_GRID (priv->dsn_list));
+	model = gnome_db_grid_get_gda_model (GNOME_DB_GRID (priv->dsn_list));
 	if (!GDA_IS_DATA_MODEL (model))
 		return;
 
@@ -295,7 +304,7 @@ foreach_remove_cb (GnomeDbGrid *grid, gint row, gpointer user_data)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 					 GTK_RESPONSE_CANCEL);
 	
-	gtk_widget_show_all (dialog);
+	gtk_widget_show (dialog);
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) 
 		gnome_db_config_remove_data_source (dsn);
 
@@ -340,7 +349,13 @@ gboolean
 dsn_config_has_selection (GtkWidget *dsn)
 {
 	DsnConfigPrivate *priv;
+	GList *list;
+	gboolean retval;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-	return gnome_db_grid_get_selection (GNOME_DB_GRID (priv->dsn_list)) != NULL;
+	list =  gnome_db_grid_get_selection (GNOME_DB_GRID (priv->dsn_list));
+	retval = list == NULL ? FALSE : TRUE;
+	if (list)
+		g_list_free (list);
+	return retval;
 }
