@@ -1,8 +1,10 @@
 /* GNOME-DB Configurator
- * Copyright (C) 2000-2002 The GNOME Foundation.
+ *
+ * Copyright (C) 2000 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +32,7 @@
 #include <libgnomedb/gnome-db-i18n.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <libgnomedb/gnome-db-data-widget.h>
 #include "provider-config.h"
 
 #define PROVIDER_CONFIG_DATA "Provider_ConfigData"
@@ -61,7 +64,7 @@ show_providers (ProviderConfigPrivate *priv)
 		value_list = g_list_append (NULL, gda_value_new_string (prv_info->id));
 		value_list = g_list_append (value_list, gda_value_new_string (prv_info->description));
 
-		gda_data_model_append_row (model, (const GList *) value_list);
+		gda_data_model_append_values (model, (const GList *) value_list);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
@@ -70,7 +73,7 @@ show_providers (ProviderConfigPrivate *priv)
 	gda_config_free_provider_list (prv_list);
 
 	/* display the new data model */
-	gnome_db_grid_set_model (GNOME_DB_GRID (priv->provider_list), model);
+	gnome_db_grid_set_gda_model (GNOME_DB_GRID (priv->provider_list), NULL, model);
 	g_object_unref (G_OBJECT (model));
 }
 
@@ -100,6 +103,8 @@ provider_config_new (void)
 
 	/* create the provider list */
 	priv->provider_list = gnome_db_grid_new ();
+	gnome_db_data_widget_global_show_actions (GNOME_DB_DATA_WIDGET (priv->provider_list), FALSE);
+	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->provider_list), 0, FALSE);
 
 	title = g_strdup_printf ("<b>%s</b>\n%s", _("Providers"),
 				 _("Installed providers"));
@@ -129,7 +134,7 @@ provider_config_new (void)
 
 	label = gnome_db_new_label_widget (
 		_("Providers are external plugins that provide access "
-		  "to a specific data source The default provider is "
+		  "to a specific data source. The default provider is "
 		  "always installed, which allows access to databases "
 		  "stored in XML files. Other providers usually "
 		  "distributed along with libgda/gnome-db include "
@@ -141,3 +146,36 @@ provider_config_new (void)
 
 	return provider;
 }
+
+void
+provider_config_select_all (GtkWidget *provider)
+{
+	ProviderConfigPrivate *priv;
+
+	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
+	gnome_db_grid_select_all (GNOME_DB_GRID (priv->provider_list));
+}
+
+void
+provider_config_unselect_all (GtkWidget *provider)
+{
+	ProviderConfigPrivate *priv;
+
+	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
+	gnome_db_grid_unselect_all (GNOME_DB_GRID (priv->provider_list));
+}
+
+gboolean
+provider_config_has_selection (GtkWidget *provider)
+{
+	ProviderConfigPrivate *priv;
+	GList *list;
+	gboolean retval;
+
+	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
+	list =  gnome_db_grid_get_selection (GNOME_DB_GRID (priv->provider_list));
+	retval = list == NULL ? FALSE : TRUE;
+	if (list)
+		g_list_free (list);
+	return retval;
+}
