@@ -75,18 +75,12 @@ glade_module_register_widgets (void)
 	glade_require ("gtk");
 	glade_require ("gnome");
 
-	glade_register_widget (GNOME_DB_TYPE_BROWSER,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_COMBO,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_CONNECTION_PROPERTIES,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_CONNECTION_SELECTOR,
-			       glade_standard_build_widget,
-			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_DATA_SOURCE_SELECTOR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
@@ -108,19 +102,13 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_FIND_DIALOG,
 			       NULL, glade_standard_build_children,
 			       gnomedb_dialog_find_internal_child);
-	glade_register_widget (GNOME_DB_TYPE_FORM,
+	glade_register_widget (GNOME_DB_FORM_TYPE,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_GRAY_BAR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_GRID,
-			       glade_standard_build_widget,
-			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_ICON_LIST,
-			       glade_standard_build_widget,
-			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_LIST,
+	glade_register_widget (GNOME_DB_GRID_TYPE,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_LOGIN,
