@@ -231,7 +231,7 @@ gnome_db_config_get_component_data_model (const gchar *query)
 		row = g_list_append (row,
 				     gda_value_new_string (info->domain));
 
-		gda_data_model_append_row (GDA_DATA_MODEL (model), row);
+		gda_data_model_append_values (GDA_DATA_MODEL (model), row);
 	}
 	
 	/* free memory */
@@ -242,6 +242,7 @@ gnome_db_config_get_component_data_model (const gchar *query)
 
 /**
  * gnome_db_config_free_component_list
+ * @list:
  */
 void
 gnome_db_config_free_component_list (GList *list)
