@@ -280,7 +280,7 @@ void
 gnome_db_window_show (GnomeDbWindow *window)
 {
 	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
-	gtk_widget_show_all (GTK_WIDGET (window));
+	gtk_widget_show (GTK_WIDGET (window));
 }
 
 /**
